! "@(#) $Id: fits2bdf.prg,v 1.1.1.1 2010/04/19 08:36:40 kbanse Exp $"
!
! Procedure to convert FITS files assuming the names
! are given by  <prefix>n.fits   where prefix can be any alpha chars. up to
! 9 characters long. The output BDF files will be <prefix>nnnn.bdf
! or a different prefix can be specified. Optionally, a window for
! extraction can also be specified.
! Oct 96 PS
!
!  Syntax:  @@ fits2bdf <prefix> n1 [n2] [<prefix>] [<window1>] [<window2>]
!
!  if n2 not given, operate on n1 only. Otherwise, use range n1 to n2
!
! Note: As full test reduction programs read keyword O_TIME(5) for determining
! the the exposure creation time, and as this is not provided by DCS but by
! INS, we generate it with an integer sequential number. This is only used to
! plot the exposure creation sequence, so it only needs to be in the right
! order.


define/param P1 ?       C  "Enter FITS filename prefix: "
define/param P2 ?       N  "First filename number sufix: "
define/param P3 0       N  "Last filename number sufix: "
define/param P4 0       C  "Enter BDF filename prefix: "
define/param P5 [1141,1901:1340,2100]     C  "Window1 to extract [x,y:x,y]:" 
define/param P6 0       C  "Window2 to extract [x,y:x,y]:" 

define/local fitsname/c/1/100 " "
define/local bdfname/c/1/25 " "
define/local i/i/1/1 0
define/local n1/i/1/1 {P2}
define/local n2/i/1/1 {P3}
define/local time/d/1/1 1.0

if "{P4}" .eq. "0" then 
  write/key P4 {P1} 
endif

do i = n1 n2
  set/format i4  
  write/key fitsname/c/1/100 "/vlt/insroot/SYSTEM/DETDATA/{P1}{i}.fits"
  write/key bdfname/c/1/25 {P4}{i}.bdf
  indisk/fits {fitsname} {bdfname}
  if M$EXIST(bdfname) .eq. 1 then
    write/out " File  {bdfname}  created."
    copy/kd time/d/1/1 {bdfname} O_TIME/d/5/1
    time = time + 1.0
  else
    write/out " Error in converting file {fitsname}. Check name."
  endif
  if "{p5}" .ne. "0" then     ! check if window requested
    rename/ima {bdfname} temporary_file_to_be_deleted
    extract/ima {bdfname} =  temporary_file_to_be_deleted{p5}
    if "{p6}" .ne. "0" then   ! check if second window given
      rename/ima {bdfname} w1_{bdfname}
      extract/ima w2_{bdfname} =  temporary_file_to_be_deleted{p6}
      write/out " Subwindows extracted: w1_{bdfname} and w2_{bdfname}"
    endif
    dele/ima temporary_file_to_be_deleted no
  endif 
enddo

write/out " "
if "{p6}" .ne. "0" then   ! check if second window given
  creat/icat w1_{p4} w1_{p4}????.bdf
  creat/icat w2_{p4} w2_{p4}????.bdf
else
  creat/icat {p4} {p4}????.bdf
endif
return  
